$ontext
Time-stamp: 	<2008-06-03 17:26:31 Shiro Takeda>

Model written in MCP format.

$offtext
*	-----------------------------------------------------------------
*	Share parameters:
display "com: Share parameters:";

parameter
    cost_y(i,r)		Total cost
    cost_va(i,r)	Value of VA
    cost_val(i,r)	Value of labor
    cost_vak(i,r)	Value of capital
    cost_van(i,r)	Value of land
    ;
*	Value of VA:
cost_va(i,r) = t_labs0(i,r) + t_caps0(i,r) + t_lnds0(i,r);
*	Total cost:
cost_y(i,r) = sum(j, t_ijs0(j,i,r)) + cost_va(i,r);
*	Value of labor:
cost_val(i,r) = t_labs0(i,r);
*	Value of capital:
cost_vak(i,r) = t_caps0(i,r);
*	Value of land:
cost_van(i,r) = t_lnds0(i,r);

display cost_va, cost_y, cost_val, cost_vak, cost_van;

parameter
    sh_x(i,r)		Share of export in total supply
    sh_va(i,r)		Share of VA in cost
    sh_val(i,r)		Share of labor
    sh_vak(i,r)		Share of capital
    sh_van(i,r)		Share of land
    sh_l(i,s,r)		Share of labor from region s in region r
    sh_k(i,s,r)		Share of capital from region s in region r
    sh_i(j,i,r)		Share of intermediate inputs
    sh_ad(i,r)		Share of domestic products
    sh_m(i,r)		Share of imported goods
    sh_d(i,s,r)		Share of goods from regions s in demand of region r
    sh_c(i,r)		Share of goods in consumption
    sh_cs(*,r)		Share of consumption and saving
    sh_inv(i,r)		Share in investment
    sh_gov(i,r)		Share in government expenditure
    sh_t(r)		Share of transfer to regions r
;

*	Share of export in total supply:
sh_x(i,r)$yd0(i,r) = ex0(i,r) / (ex0(i,r) + yd0(i,r));

*	Share of VA in cost:
sh_va(i,r)$cost_y(i,r) = cost_va(i,r) / cost_y(i,r);

*	Share of labor:
sh_val(i,r)$cost_va(i,r) = cost_val(i,r) / cost_va(i,r);
*	Share of capital:
sh_vak(i,r)$cost_va(i,r) = cost_vak(i,r) / cost_va(i,r);
*	Share of land:
sh_van(i,r)$cost_va(i,r) = cost_van(i,r) / cost_va(i,r);

*	Share of labor from region s in region r:
sh_l(i,s,r)$cost_val(i,r) = pl0(s) * labs0(i,s,r) / cost_val(i,r);
*	Share of capital from region s in region r:
sh_k(i,s,r)$cost_vak(i,r) = pk0(s) * caps0(i,s,r) / cost_vak(i,r);

*	Share of intermediate inputs:
sh_i(j,i,r)$cost_y(i,r) = t_ijs0(j,i,r) / cost_y(i,r);

*	Share of domestic products:
sh_ad(i,r)$a0(i,r) = ad0(i,r) / a0(i,r);

*	Share of imported goods:
sh_m(i,r)$a0(i,r) = sup_imp0(i,r) / a0(i,r);

*	Share of goods from regions s in demand of region r:
sh_d(i,s,r)$ad0(i,r) = sup_dom0(i,s,r) / ad0(i,r);

*	Share of goods in consumption:
sh_c(i,r) = t_cs0(i,r) / c0(r);

*	Share of consumption and saving:
sh_cs("c",r) = c0(r) / hexp0(r);
sh_cs("s",r) = inv0(r) / hexp0(r);

*	Share in investment:
sh_inv(i,r) = t_invs0(i,r) / inv0(r);

*	Share in government expenditure:
sh_gov(i,r)$gexp0(r) = t_gexps0(i,r) / gexp0(r);

*	Share of transfer to regions r:
sh_t(r) = trn0(r) / trn0("sum");

display sh_x, sh_va, sh_val, sh_vak, sh_van, sh_l, sh_k, sh_i, sh_ad, sh_m,
	sh_d, sh_c, sh_cs, sh_inv, sh_t, sh_gov;

*	-----------------------------------------------------------------
*	Variable declaration:
display "com: Variable declaration:";
variables
    y_(i,r)		Output
    a_(i,r)		Armington aggregation
    ad_(i,r)		Aggregation of domestic products
    ak_(i,r)		Aggregation of capital
    al_(i,r)		Aggregation of labor
    im_(i,r)		Import activity
    ex_(i,r)		Export activity
    exx_(i,r)		Export activity
    c_(r)		Consumption
    u_(r)		Utility
    inv_(r)		Investment
    gov_(r)		Government expenditure

    c_y_(i,r)		Unit cost of production
    c_ak_(i,r)		Unit cost of aggregation of capital
    c_al_(i,r)		Unit cost of aggregation of labor
    c_a_(i,r)		Unit cost of Armington aggregation
    c_ad_(i,r)		Unit cost of aggregation of domestic products
    c_c_(r)		Unit cost of consumption
    c_u_(r)		Unit cost of utility
    c_inv_(r)		Unit cost of investment
    c_gov_(r)		Unit cost of government expenditure

    p_y_(i,r)		Price of output
    p_va_(i,r)		Price index of VA
    p_d_(i,r)		Price of domestic goods
    p_a_(i,r)		Price index of Armington goods
    p_ad_(i,r)		Price index of aggregated domestic goods
    p_m_(i,r)		Price index of import goods
    p_x_(i,r)		Price of export goods
    p_c_(r)		Price index of consumption
    p_u_(r)		Price index of utility
    p_inv_(r)		Price index of investment goods
    p_gov_(r)		Price index of government expenditure
    p_l_(r)		Price index of labor
    p_k_(r)		Price index of captial
    p_al_(i,r)		Price of labor
    p_ak_(i,r)		Price of captial
    p_fx_		Price of foreign exchange

    a_yx_(i,r)		Export supply
    a_yd_(i,r)		Domestic supply
    a_al_(i,r)		Demand for labor
    a_ak_(i,r)		Demand for capita
    a_l_(i,s,r)		Demand for labor from regions s
    a_k_(i,s,r)		Demand for capital from regions s
    a_m_(i,r)		Import demand
    a_ad_(i,r)		Demand for domestic goods
    a_d_(i,s,r)		Demand for goods from regions s
    a_cc_(i,r)		Consumption demand
    a_c_(r)		Consumption
    a_s_(r)		Saving
    a_inv_(i,r)		Investment demand
    a_gov_(i,r)		Government expenditure demand

    m_h_(r)		Income of regional household
    m_g_		Income of central government

    a_land_(i,r)	Demand for land
    p_land_(i,r)	Price of land

    dum_evpc_		Dummy per capita EV
    trans_(r)		Transfer to regional household
    ;
*	----------------------------------------------------------------------
*	Equations declaration:
display "com: Equations declaration:";

equations
    e_y_(i,r)		Output
    e_a_(i,r)		Armington aggregation
    e_ad_(i,r)		Aggregation of domestic products
    e_ak_(i,r)		Aggregation of capital
    e_al_(i,r)		Aggregation of labor
    e_im_(i,r)		Import activity
    e_ex_(i,r)		Export activity
    e_exx_(i,r)		Export activity
    e_c_(r)		Consumption
    e_u_(r)		Utility
    e_inv_(r)		Investment
    e_gov_(r)		Government expenditure

    e_c_y_(i,r)		Unit cost of production
    e_c_ak_(i,r)	Unit cost of aggregation of capital
    e_c_al_(i,r)	Unit cost of aggregation of labor
    e_c_a_(i,r)		Unit cost of Armington aggregation
    e_c_ad_(i,r)	Unit cost of aggregation of domestic products
    e_c_c_(r)		Unit cost of consumption
    e_c_u_(r)		Unit cost of utility
    e_c_inv_(r)		Unit cost of investment
    e_c_gov_(r)		Unit cost of government expenditure

    e_p_y_(i,r)		Price of output
    e_p_va_(i,r)	Price index of VA
    e_p_d_(i,r)		Price of domestic goods
    e_p_a_(i,r)		Price index of Armington goods
    e_p_ad_(i,r)	Price index of aggregated domestic goods
    e_p_m_(i,r)		Price index of import goods
    e_p_x_(i,r)		Price of export goods
    e_p_c_(r)		Price index of consumption
    e_p_u_(r)		Price index of utility
    e_p_inv_(r)		Price index of investment goods
    e_p_gov_(r)		Price index of government expenditure
    e_p_l_(r)		Price index of labor
    e_p_k_(r)		Price index of captial
    e_p_al_(i,r)	Price of labor
    e_p_ak_(i,r)	Price of captial
    e_p_fx_		Price of foreign exchange

    e_a_yx_(i,r)	Export supply
    e_a_yd_(i,r)	Domestic supply
    e_a_al_(i,r)	Demand for labor
    e_a_ak_(i,r)	Demand for capital
    e_a_l_(i,s,r)	Demand for labor from regions s
    e_a_k_(i,s,r)	Demand for capital from regions s
    e_a_m_(i,r)		Import demand
    e_a_ad_(i,r)	Demand for domestic goods
    e_a_d_(i,s,r)	Demand for goods from regions s
    e_a_cc_(i,r)	Consumption demand
    e_a_c_(r)		Consumption
    e_a_s_(r)		Saving
    e_a_inv_(i,r)	Investment demand
    e_a_gov_(i,r)	Government expenditure demand

    e_m_h_(r)		Income of regional household
    e_m_g_		Income of central government

    e_a_land_(i,r)	Demand for land
    e_p_land_(i,r)	Price of land

    e_dum_evpc_		Dummy per capita EV
    e_trans_(r)		Transfer to regional household
;
*	----------------------------------------------------------------------
*	Equation definitions:
display "com: Equation definitions:";

*	----------------------------------------------------------------------
*	Unit cost and price index:

*	Unit cost of production:
e_c_y_(i,r)$cost_y(i,r) ..

    c_y_(i,r) =e=
    sum(j$sh_i(j,i,r), sh_i(j,i,r) * p_a_(j,r))
    + sh_va(i,r) * p_va_(i,r);

*	Unit cost of aggregation of capital:
e_c_ak_(i,r)$cost_vak(i,r) ..

    c_ak_(i,r) =e=
    ((sum(s$sh_k(i,s,r), sh_k(i,s,r) * ((1 + taxk0(s)) * p_k_(s) / pk0(s))**(1 - elas_k(i)))
    )**(1/(1 - elas_k(i)))
    )$(elas_k(i) ne 1)
    +
    (prod(s$sh_k(i,s,r), ((1 + taxk0(s)) * p_k_(s) / pk0(s))**(sh_k(i,s,r)))
    )$(elas_k(i) = 1)
    ;

*	Unit cost of aggregation of labor:
e_c_al_(i,r)$cost_val(i,r) ..

    c_al_(i,r) =e=
    ((sum(s$sh_l(i,s,r), sh_l(i,s,r) * ((1 + taxl0(s)) * p_l_(s) / pl0(s))**(1 - elas_l(i)))
    )**(1/(1 - elas_l(i)))
    )$(elas_l(i) ne 1)
    +
    (prod(s$sh_l(i,s,r), ((1 + taxl0(s)) * p_l_(s) / pl0(s))**(sh_l(i,s,r)))
    )$(elas_l(i) = 1)
    ;

*	Price index of VA:
e_p_va_(i,r)$cost_va(i,r) ..

    p_va_(i,r) =e=
    ((sh_val(i,r) * (p_al_(i,r))**(1 - elas_va(i))
	+ sh_vak(i,r) * (p_ak_(i,r))**(1 - elas_va(i))
	+ (sh_van(i,r) * (p_land_(i,r))**(1 - elas_va(i)))$sh_van(i,r)
    )**(1/(1 - elas_va(i)))
    )$(elas_va(i) ne 1)
    +
    ((p_al_(i,r))**(sh_val(i,r))
	* (p_ak_(i,r))**(sh_vak(i,r))
	* (1$(not sh_van(i,r)) + p_land_(i,r)$sh_van(i,r))**(sh_van(i,r))
    )$(elas_va(i) = 1)
;
*	Price of output:
e_p_y_(i,r)$cost_y(i,r) ..

    p_y_(i,r) =e=
    ((sh_x(i,r) * p_x_(i,r)**(1 + etra(i)))$ex0(i,r)
	+ ((1 - sh_x(i,r)) * p_d_(i,r)**(1 + etra(i)))$yd0(i,r)
    )**(1/(1 + etra(i)));

*	Unit cost of Armington aggregation:
e_c_a_(i,r)$a0(i,r)  ..

    c_a_(i,r) =e=
    ((sh_ad(i,r) * (p_ad_(i,r))**(1 - elas_dm(i))
	+ sh_m(i,r) * (p_m_(i,r))**(1 - elas_dm(i))
    )**(1/(1 - elas_dm(i)))
    )$(elas_dm(i) ne 1)
    +
    ((p_ad_(i,r))**(sh_ad(i,r))
	* (p_m_(i,r))**(sh_m(i,r))
    )$(elas_dm(i) = 1)
;
*	Unit cost of aggregation of domestic products:
e_c_ad_(i,r)$ad0(i,r) ..

    c_ad_(i,r) =e=
    ((sum(s$sh_d(i,s,r), sh_d(i,s,r) * (p_d_(i,s))**(1 - elas_dd(i)))
    )**(1/(1 - elas_dd(i)))
    )$(elas_dd(i) ne 1)
    +
    (prod(s$sh_d(i,s,r), p_d_(i,s)**(sh_d(i,s,r)))
    )$(elas_dd(i) = 1)
;
*	Unit cost of consumption:
e_c_c_(r) ..

    c_c_(r) =e=
    ((sum(i$sh_c(i,r), sh_c(i,r) * (p_a_(i,r))**(1 - elas_dd(i)))
    )**(1/(1 - elas_c))
    )$(elas_c ne 1)
    +
    (prod(i$sh_c(i,r), (p_a_(i,r)**(sh_c(i,r)))))$(elas_c = 1)
;
*	Unit cost of utility:
e_c_u_(r) ..

    c_u_(r) =e=
    (
    ((sh_cs("s",r) * (p_inv_(r))**(1-elas_u)
	+ sh_cs("c",r)* (p_c_(r))**(1-elas_u)
    )**(1/(1-elas_u))
    )$(elas_u ne 1)
    +
    ((p_inv_(r))**(sh_cs("s",r))
    * (p_c_(r))**(sh_cs("c",r))
    )$(elas_u = 1)
    )$(not fix_inv)
    +
    (p_c_(r))$fix_inv
    ;

*	Unit cost of investment:
e_c_inv_(r) ..

    c_inv_(r) =e=
    ((sum(i$sh_inv(i,r),
	sh_inv(i,r) * (p_a_(i,r))**(1-elas_inv))
    )**(1/(1-elas_inv))
    )$(elas_inv ne 1)
    +
    (prod(i$sh_inv(i,r), (p_a_(i,r))**(sh_inv(i,r))))$(elas_inv = 1)
    ;

*	Unit cost of government expenditure:
e_c_gov_(r)$fl_gov ..

    c_gov_(r) =e=
    ((sum(i$sh_gov(i,r),
	sh_gov(i,r) * (p_a_(i,r))**(1-elas_g))
    )**(1/(1-elas_g))
    )$(elas_g ne 1)
    +
    (prod(i$sh_gov(i,r), (p_a_(i,r))**(sh_gov(i,r))))$(elas_g = 1)
    ;

*	----------------------------------------------------------------------
*	Unit demand and supply functions:

*	Export supply:
e_a_yx_(i,r)$ex0(i,r) ..

    a_yx_(i,r) =e= ex0(i,r) * (p_x_(i,r) / p_y_(i,r))**(etra(i));

*	Domestic supply:
e_a_yd_(i,r)$yd0(i,r) ..

    a_yd_(i,r) =e=
    yd0(i,r) * (p_d_(i,r) / p_y_(i,r))**(etra(i));

*	Demand for labor:
e_a_al_(i,r)$t_labs0(i,r) ..

    a_al_(i,r) =e= t_labs0(i,r) * (p_va_(i,r) / p_al_(i,r))**(elas_va(i));

*	Demand for capital:
e_a_ak_(i,r)$t_caps0(i,r) ..

    a_ak_(i,r) =e= t_caps0(i,r) * (p_va_(i,r) / p_ak_(i,r))**(elas_va(i));

*	Demand for labor from regions s:
e_a_l_(i,s,r)$labs0(i,s,r) ..

    a_l_(i,s,r) =e= labs0(i,s,r) * (c_al_(i,r) / ((1+taxl0(s)) * p_l_(s) / pl0(s)))**(elas_l(i));

*	Demand for capital from regions s:
e_a_k_(i,s,r)$caps0(i,s,r) ..

    a_k_(i,s,r) =e= caps0(i,s,r) * (c_ak_(i,r) / ((1+taxk0(s)) * p_k_(s) / pk0(s)))**(elas_k(i));

*	Import demand:
e_a_m_(i,r)$sup_imp0(i,r) ..

    a_m_(i,r) =e= sup_imp0(i,r) * (c_a_(i,r) / p_m_(i,r))**(elas_dm(i));

*	Demand for domestic goods:
e_a_ad_(i,r)$ad0(i,r) ..

    a_ad_(i,r) =e= ad0(i,r) * (c_a_(i,r) / p_ad_(i,r))**(elas_dm(i));

*	Demand for goods from regions s:
e_a_d_(i,s,r)$sup_dom0(i,s,r) ..

    a_d_(i,s,r) =e=
    sup_dom0(i,s,r) * (c_ad_(i,r) / p_d_(i,s))**(elas_dd(i));

*	Consumption demand:
e_a_cc_(i,r)$t_cs0(i,r) ..

    a_cc_(i,r) =e= t_cs0(i,r) * (c_c_(r) / p_a_(i,r))**(elas_c)
    ;

*	Consumption:
e_a_c_(r) ..

    a_c_(r) =e= c0(r) * (c_u_(r) / p_c_(r))**(elas_u);

*	Saving:
e_a_s_(r) ..

    a_s_(r) =e= inv0(r) * (c_u_(r) / p_inv_(r))**(elas_u);

*	Investment demand:
e_a_inv_(i,r)$t_invs0(i,r) ..

    a_inv_(i,r) =e= t_invs0(i,r) * (c_inv_(r) / p_a_(i,r))**(elas_inv);

*	Government expenditure demand:
e_a_gov_(i,r)$(fl_gov and t_gexps0(i,r)) ..

    a_gov_(i,r) =e= t_gexps0(i,r) * (c_gov_(r) / p_a_(i,r))**(elas_g);

*	Demand for land:
e_a_land_(i,r)$t_lnds0(i,r) ..

    a_land_(i,r) =e=
    t_lnds0(i,r) * (p_va_(i,r) / p_land_(i,r))**(elas_va(i));

*	----------------------------------------------------------------------
*	Zero profit conditions:
display "com: Zero profit conditions:";

*	Output:
e_y_(i,r)$cost_y(i,r) ..

    c_y_(i,r) =g= (1 - taxy0(i,r)) * p_y_(i,r) / py0(i,r);

*	Aggregation of labor:
e_al_(i,r)$cost_val(i,r) ..

    c_al_(i,r) =g= p_al_(i,r);

*	Aggregation of capital:
e_ak_(i,r)$cost_vak(i,r) ..

    c_ak_(i,r) =g= p_ak_(i,r);

*	Armington aggregation:
e_a_(i,r)$a0(i,r) ..

    c_a_(i,r) =g= p_a_(i,r);

*	Aggregation of domestic products:
e_ad_(i,r)$ad0(i,r) ..

    c_ad_(i,r) =g= p_ad_(i,r);

*	Import activity:
e_im_(i,r)$im0(i,r) ..

    (1 + taxm0(i,r)) * p_fx_ / e_trade(i,r) =g= pm0(i,r) * p_m_(i,r);

*	Export activity:
e_ex_(i,r)$ex0(i,r) ..

    p_x_(i,r) =g= e_tot(i,r) * e_trade(i,r) * p_fx_;

*	Export activity:
e_exx_(i,r)$ex0(i,r) ..

    exx_(i,r) =g= e_tot(i,r) * e_trade(i,r) * ex0(i,r) * ex_(i,r);

*	Consumption:
e_c_(r) ..

    c_c_(r) =g= p_c_(r);

*	Utility:
e_u_(r) ..

    c_u_(r) =g= p_u_(r);

*	Investment:
e_inv_(r) ..

    c_inv_(r) =g= p_inv_(r);

*	Government expenditure:
e_gov_(r)$fl_gov ..

    c_gov_(r) =g= p_gov_(r);

*	----------------------------------------------------------------------
*	Market clearing conditions:
display "com: Market clearing conditions:";

*	Price of domestic goods:
e_p_d_(i,r)$yd0(i,r) ..

    a_yd_(i,r) * y_(i,r) =g= sum(s$sup_dom0(i,r,s), a_d_(i,r,s) * ad_(i,s));

*	Price of export goods:
e_p_x_(i,r)$ex0(i,r) ..

    a_yx_(i,r) * y_(i,r) =g=  ex0(i,r) * ex_(i,r);

*	Price index of import goods:
e_p_m_(i,r)$im0(i,r) ..

    imw0(i,r) * e_trade(i,r) * im_(i,r) =g= a_m_(i,r) * a_(i,r);

*	Price index of aggregated domestic goods:
e_p_ad_(i,r)$ad0(i,r) ..

    ad0(i,r) * ad_(i,r) =g= a_ad_(i,r) * a_(i,r);

*	Price index of Armington goods:
e_p_a_(i,r)$a0(i,r) ..

    a0(i,r) * a_(i,r) =g=
    (a_cc_(i,r) * c_(r))$t_cs0(i,r)
    + (a_inv_(i,r) * inv_(r))$t_invs0(i,r)
    + (a_gov_(i,r) * gov_(r))$t_gexps0(i,r)
    + sum(j$t_ijs0(i,j,r), t_ijs0(i,j,r) * y_(j,r));

*	Price index of investment goods:
e_p_inv_(r) ..

    inv0(r) * inv_(r) =g= (a_s_(r) * u_(r))$(not fix_inv) + (s_f * inv0(r))$fix_inv;

*	Price index of government expenditure:
e_p_gov_(r)$fl_gov ..

    gexp0(r) * gov_(r) =g= s_f * gexp0(r);

*	Price index of consumption:
e_p_c_(r) ..

    c0(r) * c_(r) =g= a_c_(r) * u_(r);

*	Price index of labor:
e_p_l_(r) ..

    s_f * lab0(r) =g= sum((i,s)$labs0(i,r,s), a_l_(i,r,s) * al_(i,s));

*	Price index of captial:
e_p_k_(r) ..

    s_f * cap0(r) =g= sum((i,s)$caps0(i,r,s), a_k_(i,r,s) * ak_(i,s));

*	Price of labor:
e_p_al_(i,r)$t_labs0(i,r) ..

    t_labs0(i,r) * al_(i,r) =g= a_al_(i,r) * y_(i,r);

*	Price of captial:
e_p_ak_(i,r)$t_caps0(i,r) ..

    t_caps0(i,r) * ak_(i,r) =g= a_ak_(i,r) * y_(i,r);

*	Price index of utility:
e_p_u_(r) ..

    m_h_(r) =g= p_u_(r) * (hexp0(r)$(not fix_inv) + c0(r)$fix_inv) * u_(r);


*	Price of foreign exchange:
e_p_fx_ ..

    sum((i,r)$ex0(i,r), exx_(i,r))
    =g= sum((i,r)$im0(i,r), im0(i,r) * im_(i,r))
    + s_f * bop0("sum");

*	Price of land:
e_p_land_(i,r)$t_lnds0(i,r) ..

    s_f * lnd0(i,r) =e= a_land_(i,r) * y_(i,r);

*	----------------------------------------------------------------------
*	Income:
display "com: Income:";

*	Income of regional household:
e_m_h_(r) ..

    m_h_(r) =e=
    p_l_(r) * s_f * lab0(r)
    + p_k_(r) * s_f * cap0(r)
    + sum(i$lnd0(i,r), p_land_(i,r) * s_f * lnd0(i,r))
    + (sh_t(r) * m_g_)$(not fl_redis)
    + trans_(r)$fl_redis
    - (p_fx_ * s_f * bop0(r))$fl_bop
    - (p_inv_(r) * s_f * inv0(r))$fix_inv
    - p_gov_(r) * s_f * gexp0(r)
;

*	Income of central government:
e_m_g_ ..

    m_g_ =e=
    sum((i,r)$yd0(i,r), taxy0(i,r) * p_y_(i,r) * (ex0(i,r) + yd0(i,r)) * y_(i,r))
    + sum((i,r,s)$labs0(i,r,s), taxl0(r) * p_l_(r) * a_l_(i,r,s) * al_(i,s))
    + sum((i,r,s)$caps0(i,r,s), taxk0(r) * p_k_(r) * a_k_(i,r,s) * ak_(i,s))
    + sum((i,r)$im0(i,r), taxm0(i,r) * p_fx_ * im0(i,r) * e_trade(i,r) * im_(i,r))
    - (p_fx_ * s_f * bop0("sum"))$(not fl_bop);

*	Dummy per capita EV:
e_dum_evpc_$fl_redis ..

    m_g_ =e= sum(r, trans_(r));

*	Transfer to regional household:
e_trans_(r)$fl_redis ..

    dum_evpc_ =e= ((u_(r) - 1) * (hexp0(r)$(not fix_inv) + c0(r)$fix_inv)) / pop(r);

*	----------------------------------------------------------------------
*	Model declaration:
display "com: Model declaration:";

model mrm_jpn_mcp Multi-region model

      / e_c_y_.c_y_, e_c_ak_.c_ak_, e_c_al_.c_al_, e_p_va_.p_va_, e_p_y_.p_y_,
      e_c_a_.c_a_, e_c_ad_.c_ad_, e_c_c_.c_c_, e_c_u_.c_u_, e_c_inv_.c_inv_, e_c_gov_.c_gov_,

      e_a_yx_.a_yx_, e_a_yd_.a_yd_, e_a_al_.a_al_, e_a_ak_.a_ak_, e_a_l_.a_l_,
      e_a_k_.a_k_, e_a_m_.a_m_, e_a_ad_.a_ad_, e_a_d_.a_d_, e_a_cc_.a_cc_, e_a_c_.a_c_,
      e_a_s_.a_s_, e_a_inv_.a_inv_, e_a_gov_.a_gov_,

      e_y_.y_, e_al_.al_, e_ak_.ak_, e_a_.a_, e_ad_.ad_, e_im_.im_, e_ex_.ex_, e_exx_.exx_,
      e_c_.c_, e_u_.u_, e_inv_.inv_, e_gov_.gov_,

      e_p_d_.p_d_, e_p_x_.p_x_, e_p_m_.p_m_,
      e_p_ad_.p_ad_, e_p_a_.p_a_, e_p_inv_.p_inv_, e_p_c_.p_c_, e_p_l_.p_l_,
      e_p_k_.p_k_, e_p_al_.p_al_, e_p_ak_.p_ak_, e_p_u_.p_u_, e_p_fx_.p_fx_,
      e_p_gov_.p_gov_,

      e_m_h_.m_h_, e_m_g_.m_g_,

      e_dum_evpc_.dum_evpc_, e_trans_.trans_,

      e_p_land_.p_land_, e_a_land_.a_land_

      /;

* ----------------------------------------------------------------------
*	Initial values for variables:
y_.l(i,r) = 1;
a_.l(i,r) = 1;
ad_.l(i,r) = 1;
ak_.l(i,r) = 1;
al_.l(i,r) = 1;
im_.l(i,r) = 1;
ex_.l(i,r) = 1;
c_.l(r) = 1;
u_.l(r) = 1;
inv_.l(r) = 1;
gov_.l(r) = 1;

c_y_.l(i,r) = 1;
c_ak_.l(i,r) = 1;
c_al_.l(i,r) = 1;
c_a_.l(i,r) = 1;
c_ad_.l(i,r) = 1;
c_c_.l(r) = 1;
c_u_.l(r) = 1;
c_inv_.l(r) = 1;
c_gov_.l(r) = 1;
p_y_.l(i,r) = 1;
p_va_.l(i,r) = 1;
p_d_.l(i,r) = 1;
p_a_.l(i,r) = 1;
p_ad_.l(i,r) = 1;
p_m_.l(i,r) = 1;
p_x_.l(i,r) = 1;
p_c_.l(r) = 1;
p_u_.l(r) = 1;
p_inv_.l(r) = 1;
p_gov_.l(r) = 1;
p_l_.l(r) = 1;
p_k_.l(r) = 1;
p_al_.l(i,r) = 1;
p_ak_.l(i,r) = 1;
p_fx_.l = 1;

a_yx_.l(i,r) = ex0(i,r);
a_yd_.l(i,r) = yd0(i,r);
a_al_.l(i,r) = t_labs0(i,r);
a_ak_.l(i,r) = t_caps0(i,r);
a_l_.l(i,s,r) = labs0(i,s,r);
a_k_.l(i,s,r) = caps0(i,s,r);
a_m_.l(i,r) = sup_imp0(i,r);
a_ad_.l(i,r) = ad0(i,r);
a_d_.l(i,s,r) = sup_dom0(i,s,r);
a_cc_.l(i,r) = t_cs0(i,r);
a_c_.l(r) = c0(r);
a_s_.l(r) = inv0(r);
a_inv_.l(i,r) = t_invs0(i,r);
a_gov_.l(i,r) = t_gexps0(i,r);

m_h_.l(r) = hexp0(r)$(not fix_inv) + c0(r)$fix_inv;
m_g_.l = trn0("sum");
exx_.l(i,r) = e_tot(i,r) * e_trade(i,r) * ex0(i,r);
trans_.l(r) = trn0(r);
dum_evpc_.l = 0;

* ----------------------------------------------------------------------
*	Lower bounds for variables:
y_.lo(i,r) = 0;
a_.lo(i,r) = 0;
ad_.lo(i,r) = 0;
ak_.lo(i,r) = 0;
al_.lo(i,r) = 0;
im_.lo(i,r) = 0;
ex_.lo(i,r) = 0;
c_.lo(r) = 0;
u_.lo(r) = 0;
inv_.lo(r) = 0;
gov_.lo(r) = 0;

c_y_.lo(i,r) = 1e-6;
c_ak_.lo(i,r) = 1e-6;
c_al_.lo(i,r) = 1e-6;
c_a_.lo(i,r) = 1e-6;
c_ad_.lo(i,r) = 1e-6;
c_c_.lo(r) = 1e-6;
c_u_.lo(r) = 1e-6;
c_inv_.lo(r) = 1e-6;
c_gov_.lo(r) = 1e-6;
p_y_.lo(i,r) = 1e-6;
p_va_.lo(i,r) = 1e-6;
p_d_.lo(i,r) = 1e-6;
p_a_.lo(i,r) = 1e-6;
p_ad_.lo(i,r) = 1e-6;
p_m_.lo(i,r) = 1e-6;
p_x_.lo(i,r) = 1e-6;
p_c_.lo(r) = 1e-6;
p_u_.lo(r) = 1e-6;
p_inv_.lo(r) = 1e-6;
p_gov_.lo(r) = 1e-6;
p_l_.lo(r) = 1e-6;
p_k_.lo(r) = 1e-6;
p_al_.lo(i,r) = 1e-6;
p_ak_.lo(i,r) = 1e-6;
p_fx_.lo = 1e-6;

a_yx_.lo(i,r) = 1e-6;
a_yd_.lo(i,r) = 1e-6;
a_al_.lo(i,r) = 1e-6;
a_ak_.lo(i,r) = 1e-6;
a_l_.lo(i,s,r) = 1e-6;
a_k_.lo(i,s,r) = 1e-6;
a_m_.lo(i,r) = 1e-6;
a_ad_.lo(i,r) = 1e-6;
a_d_.lo(i,s,r) = 1e-6;
* a_cc_.lo(i,r) = 1e-6;
* a_c_.lo(r) = 1e-6;
a_s_.lo(r) = 1e-6;
* a_inv_.lo(i,r) = 1e-6;
* a_gov_.lo(i,r) = 1e-6;

m_h_.lo(r) = 1e-6;
m_g_.lo = 1e-6;
exx_.lo(i,r) = 1e-6;

p_land_.l(i,r) = 1;
a_land_.l(i,r) = t_lnds0(i,r);

p_land_.lo(i,r) = 1e-6;
a_land_.lo(i,r) = 0;

*	Price normalization:
m_h_.fx(rnum) = m_h_.l(rnum);

* --------------------
* Local Variables:
* mode: gams
* fill-column: 80
* End:
